UaValidationResult

Struct UaValidationResult 

pub struct UaValidationResult {
    pub is_compliant: bool,
    pub level: PdfUaLevel,
    pub errors: Vec<UaComplianceError>,
    pub warnings: Vec<ComplianceWarning>,
    pub stats: UaValidationStats,
}
Result of PDF/UA validation.

Fields

is_compliant: bool

Whether the document is compliant with the target level.

level: PdfUaLevel

The level validated against.

errors: Vec<UaComplianceError>

Accessibility errors (violations).

warnings: Vec<ComplianceWarning>

Accessibility warnings (non-fatal issues).

stats: UaValidationStats

Summary statistics.

Implementations

Source

impl UaValidationResult

pub fn new(level: PdfUaLevel) -> Self

Create a new validation result for a specific level.

pub fn add_error(&mut self, error: UaComplianceError)

Add an error to the result.

pub fn add_warning(&mut self, warning: ComplianceWarning)

Add a warning to the result.

pub fn has_errors(&self) -> bool

Check if there are any errors.

pub fn has_warnings(&self) -> bool

Check if there are any warnings.