CaretAnnotation

Struct CaretAnnotation 

pub struct CaretAnnotation {
    pub rect: Rect,
    pub symbol: CaretSymbol,
    pub rd: Option<(f64, f64, f64, f64)>,
    pub contents: Option<String>,
    pub author: Option<String>,
    pub subject: Option<String>,
    pub color: Option<AnnotationColor>,
    pub flags: AnnotationFlags,
}
A Caret annotation per PDF spec Section 12.5.6.11.

Caret annotations mark a position in the document text where content should be inserted or where a correction is needed.

Fields

rect: Rect

Bounding rectangle for the caret

symbol: CaretSymbol

Symbol to display (None or Paragraph)

rd: Option<(f64, f64, f64, f64)>

Optional rectangle difference for the caret

contents: Option<String>

Contents/comment

author: Option<String>

Author

subject: Option<String>

Subject

color: Option<AnnotationColor>

Color

flags: AnnotationFlags

Annotation flags

Implementations

Source

impl CaretAnnotation

pub fn new(rect: Rect) -> Self

Create a new caret annotation.

pub fn paragraph(rect: Rect) -> Self

Create a caret with paragraph symbol.

pub fn with_symbol(self, symbol: CaretSymbol) -> Self

Set the caret symbol.

pub fn with_rd(self, left: f64, bottom: f64, right: f64, top: f64) -> Self

Set the rectangle difference (RD).

pub fn with_contents(self, contents: impl Into<String>) -> Self

Set contents/comment.

pub fn with_author(self, author: impl Into<String>) -> Self

Set the author.

pub fn with_subject(self, subject: impl Into<String>) -> Self

Set the subject.

pub fn with_color(self, color: AnnotationColor) -> Self

Set the color.

pub fn with_flags(self, flags: AnnotationFlags) -> Self

Set annotation flags.

pub fn build(&self, _page_refs: &[ObjectRef]) -> HashMap<String, Object>

Build the annotation dictionary.

pub fn rect(&self) -> Rect

Get the bounding rectangle.