pub struct LinearGradientBuilder { /* private fields */ }Expand description
Builder for linear (axial) gradients.
Creates PDF Type 2 (Axial) shading that interpolates colors along a line between two points.
Implementations
Sourceimpl LinearGradientBuilder
impl LinearGradientBuilder
Sourcepub fn extend_start(self, extend: bool) -> Self
pub fn extend_start(self, extend: bool) -> Self
Set whether to extend the gradient before the start point.
Sourcepub fn extend_end(self, extend: bool) -> Self
pub fn extend_end(self, extend: bool) -> Self
Set whether to extend the gradient after the end point.