pub struct ObjectSerializer { /* private fields */ }Expand description
Serializer for PDF objects.
Converts PDF Object types to their byte representation following the PDF specification syntax rules.
Implementations
Sourceimpl ObjectSerializer
impl ObjectSerializer
Sourcepub fn serialize_to_string(&self, obj: &Object) -> String
pub fn serialize_to_string(&self, obj: &Object) -> String
Serialize an object to a string (for debugging).
Sourcepub fn serialize_indirect(&self, id: u32, gen: u16, obj: &Object) -> Vec<u8> ⓘ
pub fn serialize_indirect(&self, id: u32, gen: u16, obj: &Object) -> Vec<u8> ⓘ
Serialize an indirect object definition.
Format: {id} {gen} obj\n{object}\nendobj\n
Sourcepub fn serialize_indirect_encrypted(
&self,
id: u32,
gen: u16,
obj: &Object,
handler: &EncryptionWriteHandler,
) -> Vec<u8> ⓘ
pub fn serialize_indirect_encrypted( &self, id: u32, gen: u16, obj: &Object, handler: &EncryptionWriteHandler, ) -> Vec<u8> ⓘ
Serialize an indirect object with encryption.
Format: {id} {gen} obj\n{encrypted_object}\nendobj\n
Strings and stream data within the object are encrypted using the provided encryption handler.