Content stream parser.
This module parses PDF content streams into a sequence of operators. Content streams are fundamentally different from the main PDF structure: they use a postfix notation where operands come before operators.
Example content stream:
BT
/F1 12 Tf
100 700 Td
(Hello, World!) Tj
ETFunctions
- parse_
and_ execute_ text_ only - Streaming text-only parser: parse operators and call handler immediately.
- parse_
content_ stream - Parse a content stream into a sequence of operators.
- parse_
content_ stream_ images_ only - Image-only content stream parser: skips BT/ET text blocks entirely.
- parse_
content_ stream_ paths_ only - Parse a content stream for path extraction, skipping BT/ET text blocks.
- parse_
content_ stream_ text_ only - Parse a content stream for text extraction, skipping pure graphics operators.